@@ -304,7 +304,7 @@ public final class IOUtilsContentEqualsReadersBenchmark_testStringCurrent_jmhTes
             }
             int opsPerInv = control.benchmarkParams.getOpsPerInvocation();
             long totalOps = opsPerInv;
-            BenchmarkTaskResult results = new BenchmarkTaskResult((long)totalOps, (long)totalOps);
+            BenchmarkTaskResult results = new BenchmarkTaskResult(totalOps, totalOps);
             results.add(new SingleShotResult(ResultRole.PRIMARY, "testStringCurrent", res.getTime(), benchmarkParams.getTimeUnit()));
             this.blackhole.evaporate("Yes, I am Stephen Hawking, and know a thing or two about black holes.");
             return results;
